@@ -2,7 +2,7 @@ import numpy as np
 import torch
 from pdb import set_trace
 from scipy.optimize import linear_sum_assignment
-from src.tensor_funcs import numpyify
+from dl_utils.tensor_funcs import numpyify
 
 
 def unique_labels(labels):
